pilas.comportamientos.Comportamiento

Package pilas :: Module comportamientos :: Class Comportamiento |
[hide private]
[frames] | no frames]

# Class Comportamiento

source code

    object --+
             |
            Comportamiento

Known Subclasses:
  - Avanzar
  - , Girar
  - , Proyectil
  - , Saltar
  - , actores.cooperativista.Caminando
  - , actores.cooperativista.DecirOk
  - , actores.cooperativista.Esperando
  - , actores.personajes_rpg.Esperando
  - , actores.pingu.Caminando
  - , actores.pingu.Esperando
  - , actores.pingu.Saltando
  - , actores.martian.Esperando
  - , actores.martian.Disparar
  - , actores.martian.Saltando

Representa un comportamiento (estrategia) que se puede anexar a un actor.

Instance Methods | [hide private]
actualizar(self) Actualiza el comportamiento en un instante dado. | source code
iniciar(self, receptor) Se invoca cuando se anexa el comportamiento a un actor. | source code
terminar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### actualizar(self) | source code
Actualiza el comportamiento en un instante dado. Si este metodo retorna True entonces el actor dejará de ejecutar este comportamiento.

### iniciar(self, receptor) | source code
Se invoca cuando se anexa el comportamiento a un actor. :param receptor: El actor que comenzará a ejecutar este comportamiento.